@@ -1,7 +1,5 @@
 package Form::Processor;
-{
-  $Form::Processor::VERSION = '1.122970';
-}
+$Form::Processor::VERSION = '1.162360';
 use strict;
 use warnings;
 use base qw/ Rose::Object  Form::Processor::Model /;
@@ -429,7 +427,7 @@ sub exists {
 sub init_language_handle {
     my $self = shift;
 
-    my $lh = $ENV{LANGUAGE_HANDLE} || Form::Processor::I18N->get_handle ||
+    my $lh = $Form::Processor::LANGUAGE_HANDLE || $ENV{LANGUAGE_HANDLE} || Form::Processor::I18N->get_handle ||
         die "Failed call to Text::Maketext->get_handle";
 
     return $lh;
@@ -677,21 +675,19 @@ sub parent_field {
 
 1;
 
-
-
-
-
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Processor - validate and process form data
 
 =head1 VERSION
 
-version 1.122970
+version 1.162360
 
 =head1 SYNOPSIS
 
@@ -1457,8 +1453,9 @@ Returns true (the field) if the field exists
 =item language_handle
 
 Set or get the Locale::Maketext language handle.  If not set will look for a
-language handle in the environment variable $ENV{LANGUAGE_HANDLE} and
-otherwise will Create a default language handler using the name space:
+language handle in the global variable $Form::Processor::LANGUAGE_HANDLE, then
+the  environment variable $ENV{LANGUAGE_HANDLE} and otherwise will Create a 
+default language handler using the name space:
 
     Form::Processor::I18N
 
@@ -1669,4 +1666,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
