@@ -1,7 +1,5 @@
 package Form::Processor::Field;
-{
-  $Form::Processor::Field::VERSION = '1.122970';
-}
+$Form::Processor::Field::VERSION = '1.162360';
 use strict;
 use warnings;
 use base 'Rose::Object';
@@ -158,7 +156,7 @@ sub add_error {
         $error_field = $form->parent_field if $form->parent_field;
     }
     else {
-        $lh = $ENV{LANGUAGE_HANDLE} || Form::Processor::I18N->get_handle ||
+        $lh = $Form::Processor::LANGUAGE_HANDLE || $ENV{LANGUAGE_HANDLE} || Form::Processor::I18N->get_handle ||
             die "Failed call to Text::Maketext->get_handle";
     }
 
@@ -446,17 +444,19 @@ sub dump {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Processor::Field - Base class for Fields used with Form::Processor
 
 =head1 VERSION
 
-version 1.122970
+version 1.162360
 
 =head1 SYNOPSIS
 
@@ -901,4 +901,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
